%SERIALPORT M-Code for communicating with an instrument.
%
%   This is the machine generated representation of an instrument control
%   session. The instrument control session comprises all the steps you are
%   likely to take when communicating with your instrument. These steps are:
%   
%       1. Create an instrument object
%       2. Connect to the instrument
%       3. Configure properties
%       4. Write and read data
%       5. Disconnect from the instrument
% 
%   To run the instrument control session, type the name of the M-file,
%   serialPort, at the MATLAB command prompt.
% 
%   The M-file, SERIALPORT.M must be on your MATLAB PATH. For additional information 
%   on setting your MATLAB PATH, type 'help addpath' at the MATLAB command 
%   prompt.
% 
%   Example:
%       serialport;
% 
%   See also SERIAL, GPIB, TCPIP, UDP, VISA.
% 
 
%   Creation time: 08-May-2008 15:40:08

% Create a serial port object.
objSerial1 = instrfind('Type', 'serial', 'Port', 'COM83', 'Tag', '');

% Create the serial port object if it does not exist
% otherwise use the object that was found.
if isempty(objSerial1)
    objSerial1 = serial('COM83');
else
    fclose(objSerial1);
    objSerial1 = objSerial1(1);
end

objSerial1.InputBufferSize = 131400;
objSerial1.BaudRate = 460800;
objSerial1.ReadAsyncMode = 'continuous';
% objSerial1.BytesAvailableFcnMode = 'byte';
% objSerial1.BytesAvailableFcnCount = 65536;
% objSerial1.BytesAvailableFcn = @readSerial;

% Connect to instrument object, objSerial1.
fopen(objSerial1);

% get(objSerial1,{'BaudRate','DataBits','Parity','StopBits','Terminator'})

fwrite(objSerial1,3,'uint8');
fwrite(objSerial1,16,'uint8');
bytesAvl = -1;
while(1)
    pause(0.5);
    bytesAvlOld = bytesAvl;
    bytesAvl = objSerial1.BytesAvailable;
    if(bytesAvl == bytesAvlOld && mod(bytesAvl,2) == 0)
        d1 = fread(objSerial1,objSerial1.BytesAvailable,'uint8');
        break;
    end
end

fwrite(objSerial1,3,'uint8');
fwrite(objSerial1,17,'uint8');
bytesAvl = -1;
while(1)
    pause(0.5);
    bytesAvlOld = bytesAvl;
    bytesAvl = objSerial1.BytesAvailable;
    if(bytesAvl == bytesAvlOld && mod(bytesAvl,2) == 0)
        d2 = fread(objSerial1,objSerial1.BytesAvailable,'uint8');
        break;
    end
end

fprintf('\nFPGA version is 0.%d\n\n',d1(1));
fprintf('Further details are %d\n\n',d2(1));